summaryrefslogtreecommitdiff
path: root/src/lib/image.cc
diff options
context:
space:
mode:
authorCarl Hetherington <cth@carlh.net>2018-01-10 01:00:14 +0000
committerCarl Hetherington <cth@carlh.net>2018-01-10 01:00:14 +0000
commitf59ae2d9793699fd0e18f9e53ff362c26c2ef00c (patch)
tree5e4e1e0bf7872e1c5dd581b5b6cb255d9a20ebb1 /src/lib/image.cc
parent1d7a98b5c7537b4874645c56cd83ece9f78625f5 (diff)
Fix yet more pixel order confusions.
Diffstat (limited to 'src/lib/image.cc')
-rw-r--r--src/lib/image.cc22
1 files changed, 11 insertions, 11 deletions
diff --git a/src/lib/image.cc b/src/lib/image.cc
index 827ece5fd..cb03e1a73 100644
--- a/src/lib/image.cc
+++ b/src/lib/image.cc
@@ -429,7 +429,7 @@ Image::make_black ()
void
Image::make_transparent ()
{
- if (_pixel_format != AV_PIX_FMT_RGBA) {
+ if (_pixel_format != AV_PIX_FMT_BGRA) {
throw PixelFormatError ("make_transparent()", _pixel_format);
}
@@ -439,8 +439,8 @@ Image::make_transparent ()
void
Image::alpha_blend (shared_ptr<const Image> other, Position<int> position)
{
- /* We're blending RGBA images; first byte is red, second byte is green, third byte blue, fourth byte alpha */
- DCPOMATIC_ASSERT (other->pixel_format() == AV_PIX_FMT_RGBA);
+ /* We're blending BGRA images; first byte is blue, second byte is green, third byte red, fourth byte alpha */
+ DCPOMATIC_ASSERT (other->pixel_format() == AV_PIX_FMT_BGRA);
int const other_bpp = 4;
int start_tx = position.x;
@@ -469,9 +469,9 @@ Image::alpha_blend (shared_ptr<const Image> other, Position<int> position)
uint8_t* op = other->data()[0] + oy * other->stride()[0];
for (int tx = start_tx, ox = start_ox; tx < size().width && ox < other->size().width; ++tx, ++ox) {
float const alpha = float (op[3]) / 255;
- tp[0] = op[0] * alpha + tp[0] * (1 - alpha);
+ tp[0] = op[2] * alpha + tp[0] * (1 - alpha);
tp[1] = op[1] * alpha + tp[1] * (1 - alpha);
- tp[2] = op[2] * alpha + tp[2] * (1 - alpha);
+ tp[2] = op[0] * alpha + tp[2] * (1 - alpha);
tp += this_bpp;
op += other_bpp;
@@ -487,9 +487,9 @@ Image::alpha_blend (shared_ptr<const Image> other, Position<int> position)
uint8_t* op = other->data()[0] + oy * other->stride()[0];
for (int tx = start_tx, ox = start_ox; tx < size().width && ox < other->size().width; ++tx, ++ox) {
float const alpha = float (op[3]) / 255;
- tp[0] = op[2] * alpha + tp[0] * (1 - alpha);
+ tp[0] = op[0] * alpha + tp[0] * (1 - alpha);
tp[1] = op[1] * alpha + tp[1] * (1 - alpha);
- tp[2] = op[0] * alpha + tp[2] * (1 - alpha);
+ tp[2] = op[2] * alpha + tp[2] * (1 - alpha);
tp[3] = op[3] * alpha + tp[3] * (1 - alpha);
tp += this_bpp;
@@ -506,9 +506,9 @@ Image::alpha_blend (shared_ptr<const Image> other, Position<int> position)
uint8_t* op = other->data()[0] + oy * other->stride()[0];
for (int tx = start_tx, ox = start_ox; tx < size().width && ox < other->size().width; ++tx, ++ox) {
float const alpha = float (op[3]) / 255;
- tp[0] = op[0] * alpha + tp[0] * (1 - alpha);
+ tp[0] = op[2] * alpha + tp[0] * (1 - alpha);
tp[1] = op[1] * alpha + tp[1] * (1 - alpha);
- tp[2] = op[2] * alpha + tp[2] * (1 - alpha);
+ tp[2] = op[0] * alpha + tp[2] * (1 - alpha);
tp[3] = op[3] * alpha + tp[3] * (1 - alpha);
tp += this_bpp;
@@ -526,9 +526,9 @@ Image::alpha_blend (shared_ptr<const Image> other, Position<int> position)
for (int tx = start_tx, ox = start_ox; tx < size().width && ox < other->size().width; ++tx, ++ox) {
float const alpha = float (op[3]) / 255;
/* Blend high bytes */
- tp[1] = op[0] * alpha + tp[1] * (1 - alpha);
+ tp[1] = op[2] * alpha + tp[1] * (1 - alpha);
tp[3] = op[1] * alpha + tp[3] * (1 - alpha);
- tp[5] = op[2] * alpha + tp[5] * (1 - alpha);
+ tp[5] = op[0] * alpha + tp[5] * (1 - alpha);
tp += this_bpp;
op += other_bpp;